@@ -1,21 +1,26 @@
 from fastapi import FastAPI, File, status, Request, UploadFile, Form, HTTPException
 from unstructured_inference.inference.layout import process_data_with_model
-from unstructured_inference.models import UnknownModelException
+from unstructured_inference.models.base import UnknownModelException
 from typing import List
 
 app = FastAPI()
 
 ALL_ELEMS = "_ALL"
+VALID_FILETYPES = ["pdf", "image"]
 
 
-@app.post("/layout/pdf")
-async def layout_parsing_pdf(
+@app.post("/layout/{filetype:path}")
+async def layout_parsing(
+    filetype: str,
     file: UploadFile = File(),
     include_elems: List[str] = Form(default=ALL_ELEMS),
     model: str = Form(default=None),
 ):
+    if filetype not in VALID_FILETYPES:
+        raise HTTPException(status.HTTP_404_NOT_FOUND)
+    is_image = filetype == "image"
     try:
-        layout = process_data_with_model(file.file, model)
+        layout = process_data_with_model(file.file, model, is_image)
     except UnknownModelException as e:
         raise HTTPException(status.HTTP_422_UNPROCESSABLE_ENTITY, str(e))
     pages_layout = [
